@@ -1,4 +1,4 @@
-/* Copyright 2007,2008,2010,2012,2021 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2007,2008,2010,2012,2018,2021 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -48,6 +48,8 @@
 /**                                 to   : 27 nov 2012     **/
 /**                # Version 6.1  : from : 18 jun 2021     **/
 /**                                 to   : 04 dec 2021     **/
+/**                # Version 7.0  : from : 04 aug 2018     **/
+/**                                 to   : 04 aug 2018     **/
 /**                                                        **/
 /**   NOTES      : # The definitions of MPI_Gather and     **/
 /**                  MPI_Gatherv indicate that elements in **/
@@ -241,7 +243,6 @@ const int                     protnum)            /* -1 means allgather */
     cgrfptr->edlotax = edlotax;
     cgrfptr->edlosum = edlosum;
     cgrfptr->degrmax = dgrfptr->degrglbmax;
-    cgrfptr->procptr = NULL;                      /* This field exists only when compiled with SCOTCH_PTSCOTCH */
   }
 #ifdef SCOTCH_DEBUG_DGRAPH2                       /* Prevent Valgrind from yelling */
   else {                                          /* Process is not root           */
